==> jc-1.4.0.tar.gz: java/text/Format__24Field.h <==
// public class java.text.Format$Field

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d8de555b0e6a3b60 java_text_AttributedCharacterIterator__24Attribute
// @dep_class 732f8dfeca4d477 java_text_Format__24Field

// header file dependencies
// @dep_header java_text_AttributedCharacterIterator__24Attribute

#include "java/text/AttributedCharacterIterator__24Attribute.h"

#ifndef _JC_java_text_Format__24Field_H_
#define _JC_java_text_Format__24Field_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_Format__24Field$sub_refs	_jc_java_text_Format__24Field$sub_refs;
typedef struct _jc_java_text_Format__24Field$sub_nonrefs	_jc_java_text_Format__24Field$sub_nonrefs;
typedef struct _jc_java_text_Format__24Field$refs	_jc_java_text_Format__24Field$refs;
typedef struct _jc_java_text_Format__24Field$nonrefs	_jc_java_text_Format__24Field$nonrefs;
typedef struct _jc_java_text_Format__24Field$object	_jc_java_text_Format__24Field$object;

typedef struct _jc_java_text_Format__24Field$fields_struct	_jc_java_text_Format__24Field$fields_struct;
typedef const struct _jc_java_text_Format__24Field$vmethods	_jc_java_text_Format__24Field$vmethods;
typedef const struct _jc_java_text_Format__24Field$vtable	_jc_java_text_Format__24Field$vtable;
typedef const struct _jc_java_text_Format__24Field$vtype	_jc_java_text_Format__24Field$vtype;

// Class fields structure
struct _jc_java_text_Format__24Field$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_text_Format__24Field$fields_struct _jc_java_text_Format__24Field$class_fields;

// Constructors
extern void _jc_java_text_Format__24Field$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_text_Format__24Field$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_text_Format__24Field$vmethods {
};

// Vtable
struct _jc_java_text_Format__24Field$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	java_text_AttributedCharacterIterator__24Attribute;
	_jc_java_text_Format__24Field$vmethods	java_text_Format__24Field;
};

// Vtype
struct _jc_java_text_Format__24Field$vtype {
	_jc_type			type;
	_jc_java_text_Format__24Field$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_Format__24Field$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_text_Format__24Field$refs {
    _jc_java_text_Format__24Field$sub_refs	java_text_Format__24Field;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_Format__24Field$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_text_Format__24Field$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_text_Format__24Field$sub_nonrefs	java_text_Format__24Field;
};

// Object instance structure
struct _jc_java_text_Format__24Field$object {
	_jc_java_text_Format__24Field$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_Format__24Field$vtype	*vtype;
	_jc_java_text_Format__24Field$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_Format__24Field$vtype _jc_java_text_Format__24Field$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_Format__24Field, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_Format__24Field$class_object;

#endif	/* _JC_java_text_Format__24Field_H_ */

==> jc-1.4.6.tar.gz: java/text/Format__24Field.h <==
// public class java.text.Format$Field

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d8de555b0e6a3b60 java_text_AttributedCharacterIterator__24Attribute
// @dep_class 732f8dfeca4d477 java_text_Format__24Field

// header file dependencies
// @dep_header java_text_AttributedCharacterIterator__24Attribute

#include "java/text/AttributedCharacterIterator__24Attribute.h"

#ifndef _JC_java_text_Format__24Field_H_
#define _JC_java_text_Format__24Field_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_Format__24Field$sub_refs	_jc_java_text_Format__24Field$sub_refs;
typedef struct _jc_java_text_Format__24Field$sub_nonrefs	_jc_java_text_Format__24Field$sub_nonrefs;
typedef struct _jc_java_text_Format__24Field$refs	_jc_java_text_Format__24Field$refs;
typedef struct _jc_java_text_Format__24Field$nonrefs	_jc_java_text_Format__24Field$nonrefs;
typedef struct _jc_java_text_Format__24Field$object	_jc_java_text_Format__24Field$object;

typedef struct _jc_java_text_Format__24Field$fields_struct	_jc_java_text_Format__24Field$fields_struct;
typedef const struct _jc_java_text_Format__24Field$vmethods	_jc_java_text_Format__24Field$vmethods;
typedef const struct _jc_java_text_Format__24Field$vtable	_jc_java_text_Format__24Field$vtable;
typedef const struct _jc_java_text_Format__24Field$vtype	_jc_java_text_Format__24Field$vtype;

// Class fields structure
struct _jc_java_text_Format__24Field$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_text_Format__24Field$fields_struct _jc_java_text_Format__24Field$class_fields;

// Constructors
extern void _jc_java_text_Format__24Field$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_text_Format__24Field$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_text_Format__24Field$vmethods {
};

// Vtable
struct _jc_java_text_Format__24Field$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_AttributedCharacterIterator__24Attribute$vmethods	java_text_AttributedCharacterIterator__24Attribute;
	_jc_java_text_Format__24Field$vmethods	java_text_Format__24Field;
};

// Vtype
struct _jc_java_text_Format__24Field$vtype {
	_jc_type			type;
	_jc_java_text_Format__24Field$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_Format__24Field$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_text_Format__24Field$refs {
    _jc_java_text_Format__24Field$sub_refs	java_text_Format__24Field;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_refs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_Format__24Field$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_text_Format__24Field$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_AttributedCharacterIterator__24Attribute$sub_nonrefs	java_text_AttributedCharacterIterator__24Attribute;
    _jc_java_text_Format__24Field$sub_nonrefs	java_text_Format__24Field;
};

// Object instance structure
struct _jc_java_text_Format__24Field$object {
	_jc_java_text_Format__24Field$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_Format__24Field$vtype	*vtype;
	_jc_java_text_Format__24Field$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_Format__24Field$vtype _jc_java_text_Format__24Field$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_Format__24Field, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_Format__24Field$class_object;

#endif	/* _JC_java_text_Format__24Field_H_ */
